@@ -1,11 +1,14 @@
+"""
+    (Alembic) - SQLAlchemy Migrations Tool
+"""
 from logging.config import fileConfig
 
+import main
 from alembic import context
+from sqlalchemy import engine_from_config, pool
 
 # Custom Settings
 import fastberry as fb
-import main
-from sqlalchemy import engine_from_config, pool
 
 # this is the Alembic Config object, which provides
 # access to the values within the .ini file in use.
